summaryrefslogtreecommitdiff
path: root/internal/cmd
diff options
context:
space:
mode:
Diffstat (limited to 'internal/cmd')
-rw-r--r--internal/cmd/release.go10
-rw-r--r--internal/cmd/showcase.go4
-rw-r--r--internal/cmd/sync.go2
3 files changed, 8 insertions, 8 deletions
diff --git a/internal/cmd/showcase.go b/internal/cmd/showcase.go
index 3217318..d6d8faf 100644
--- a/internal/cmd/showcase.go
+++ b/internal/cmd/showcase.go
@@ -22,7 +22,7 @@ var showcaseCmd = &cobra.Command{
Short: "Generate AI-powered project showcase",
Long: `Generate a comprehensive showcase of all your projects using AI.
This feature creates a formatted document with project summaries, statistics,
-and code snippets. By default uses opencode (local Ollama), with fallback to amp, hexai, and claude.`,
+and code snippets. By default uses opencode (via ollama launch with glm-5.1:cloud), with fallback to hexai, claude, and amp.`,
Example: ` # Generate showcase with cached summaries
gitsyncer showcase
@@ -63,6 +63,6 @@ func init() {
showcaseCmd.Flags().StringVarP(&outputPath, "output", "o", "", "custom output eath (default: ~/git/foo.zone-content/gemtext/about/showcase.gmi.tpl)")
showcaseCmd.Flags().StringVar(&outputFormat, "format", "gemtext", "output format: gemtext, markdown, html")
showcaseCmd.Flags().StringVar(&excludePattern, "exclude", "", "exclude repos matching pattern")
- showcaseCmd.Flags().StringVar(&showcaseAITool, "ai-tool", "opencode", "AI tool for summaries: opencode, amp, hexai, claude, or claude-code (default tries opencode→amp→hexai→claude)")
+ showcaseCmd.Flags().StringVar(&showcaseAITool, "ai-tool", "opencode", "AI tool for summaries: opencode, hexai, claude, amp, or claude-code (default tries opencode→hexai→claude→amp)")
showcaseCmd.Flags().StringVar(&showcaseRepo, "repo", "", "only generate showcase for a single repository")
}
diff --git a/internal/cmd/sync.go b/internal/cmd/sync.go
index a4fff84..ea4cb8a 100644
--- a/internal/cmd/sync.go
+++ b/internal/cmd/sync.go
@@ -194,7 +194,7 @@ func init() {
syncCmd.PersistentFlags().BoolVar(&noReleases, "no-releases", false, "skip release checking after sync")
syncCmd.PersistentFlags().BoolVar(&autoCreate, "auto-create-releases", false, "automatically create releases without confirmation")
syncCmd.PersistentFlags().BoolVar(&noAIReleaseNotes, "no-ai-release-notes", false, "disable AI-generated release notes (AI notes are enabled by default)")
- syncCmd.PersistentFlags().StringVar(&syncAITool, "ai-tool", "opencode", "AI tool to use for release notes when auto-creating (opencode, amp, claude, or hexai; opencode is tried first if available)")
+ syncCmd.PersistentFlags().StringVar(&syncAITool, "ai-tool", "opencode", "AI tool to use for release notes when auto-creating (opencode, hexai, claude, or amp; opencode is tried first if available)")
syncCmd.PersistentFlags().BoolVarP(&syncForce, "force", "f", false, "force sync even if normal sync interval checks would skip a repository")
syncCmd.PersistentFlags().BoolVar(&throttle, "throttle", false, "throttle syncing based on local repo activity")
}
diff --git a/internal/cmd/release.go b/internal/cmd/release.go
index 88ce86b..5216b17 100644
--- a/internal/cmd/release.go
+++ b/internal/cmd/release.go
@@ -19,8 +19,8 @@ var releaseCmd = &cobra.Command{
Use: "release",
Short: "Manage releases across platforms",
Long: `Check for version tags without releases and create them across
-GitHub and Codeberg. Supports AI-generated release notes via amp (stdin pipeline),
-with fallback to hexai or Claude.`,
+GitHub and Codeberg. Supports AI-generated release notes via opencode (launch run with glm-5.1:cloud),
+with fallback to hexai, claude, or amp.`,
}
var releaseCheckCmd = &cobra.Command{
@@ -74,8 +74,8 @@ If no repository is specified, processes all configured repositories.`,
# Create for specific repository without AI
gitsyncer release create myproject --no-ai-notes
- # Use amp for AI release notes
-gitsyncer release create --ai-tool amp`,
+ # Use opencode for AI release notes
+ gitsyncer release create --ai-tool opencode`,
Run: func(cmd *cobra.Command, args []string) {
flags := buildFlags()
flags.CheckReleases = true
@@ -109,5 +109,5 @@ func init() {
releaseCreateCmd.Flags().BoolVar(&noAINotes, "no-ai-notes", false, "disable AI-generated release notes (AI notes are enabled by default)")
releaseCreateCmd.Flags().BoolVar(&updateExisting, "update-existing", false, "update existing releases with new AI-generated notes")
releaseCreateCmd.Flags().StringVar(&templatePath, "template", "", "custom template for release notes")
- releaseCreateCmd.Flags().StringVar(&aiTool, "ai-tool", "amp", "AI tool to use for release notes (amp, claude, or hexai; amp is tried first if available)")
+ releaseCreateCmd.Flags().StringVar(&aiTool, "ai-tool", "opencode", "AI tool to use for release notes (opencode, hexai, claude, or amp; opencode is tried first if available)")
}